@@ -48,27 +48,25 @@
 #endif /* !G_ENABLE_DEBUG */
 
 
-/* BOOLEAN:STRING,STRING,STRING,FLAGS (./gio-marshal.list:1) */
+/* VOID:STRING,STRING,STRING,FLAGS (./gio-marshal.list:1) */
 void
-_gio_marshal_BOOLEAN__STRING_STRING_STRING_FLAGS (GClosure     *closure,
-                                                  GValue       *return_value G_GNUC_UNUSED,
-                                                  guint         n_param_values,
-                                                  const GValue *param_values,
-                                                  gpointer      invocation_hint G_GNUC_UNUSED,
-                                                  gpointer      marshal_data)
+_gio_marshal_VOID__STRING_STRING_STRING_FLAGS (GClosure     *closure,
+                                               GValue       *return_value G_GNUC_UNUSED,
+                                               guint         n_param_values,
+                                               const GValue *param_values,
+                                               gpointer      invocation_hint G_GNUC_UNUSED,
+                                               gpointer      marshal_data)
 {
-  typedef gboolean (*GMarshalFunc_BOOLEAN__STRING_STRING_STRING_FLAGS) (gpointer     data1,
-                                                                        gpointer     arg_1,
-                                                                        gpointer     arg_2,
-                                                                        gpointer     arg_3,
-                                                                        guint        arg_4,
-                                                                        gpointer     data2);
-  register GMarshalFunc_BOOLEAN__STRING_STRING_STRING_FLAGS callback;
+  typedef void (*GMarshalFunc_VOID__STRING_STRING_STRING_FLAGS) (gpointer     data1,
+                                                                 gpointer     arg_1,
+                                                                 gpointer     arg_2,
+                                                                 gpointer     arg_3,
+                                                                 guint        arg_4,
+                                                                 gpointer     data2);
+  register GMarshalFunc_VOID__STRING_STRING_STRING_FLAGS callback;
   register GCClosure *cc = (GCClosure*) closure;
   register gpointer data1, data2;
-  gboolean v_return;
 
-  g_return_if_fail (return_value != NULL);
   g_return_if_fail (n_param_values == 5);
 
   if (G_CCLOSURE_SWAP_DATA (closure))
@@ -81,37 +79,33 @@ _gio_marshal_BOOLEAN__STRING_STRING_STRING_FLAGS (GClosure     *closure,
       data1 = g_value_peek_pointer (param_values + 0);
       data2 = closure->data;
     }
-  callback = (GMarshalFunc_BOOLEAN__STRING_STRING_STRING_FLAGS) (marshal_data ? marshal_data : cc->callback);
+  callback = (GMarshalFunc_VOID__STRING_STRING_STRING_FLAGS) (marshal_data ? marshal_data : cc->callback);
 
-  v_return = callback (data1,
-                       g_marshal_value_peek_string (param_values + 1),
-                       g_marshal_value_peek_string (param_values + 2),
-                       g_marshal_value_peek_string (param_values + 3),
-                       g_marshal_value_peek_flags (param_values + 4),
-                       data2);
-
-  g_value_set_boolean (return_value, v_return);
+  callback (data1,
+            g_marshal_value_peek_string (param_values + 1),
+            g_marshal_value_peek_string (param_values + 2),
+            g_marshal_value_peek_string (param_values + 3),
+            g_marshal_value_peek_flags (param_values + 4),
+            data2);
 }
 
-/* BOOLEAN:STRING,BOXED (./gio-marshal.list:2) */
+/* VOID:STRING,BOXED (./gio-marshal.list:2) */
 void
-_gio_marshal_BOOLEAN__STRING_BOXED (GClosure     *closure,
-                                    GValue       *return_value G_GNUC_UNUSED,
-                                    guint         n_param_values,
-                                    const GValue *param_values,
-                                    gpointer      invocation_hint G_GNUC_UNUSED,
-                                    gpointer      marshal_data)
+_gio_marshal_VOID__STRING_BOXED (GClosure     *closure,
+                                 GValue       *return_value G_GNUC_UNUSED,
+                                 guint         n_param_values,
+                                 const GValue *param_values,
+                                 gpointer      invocation_hint G_GNUC_UNUSED,
+                                 gpointer      marshal_data)
 {
-  typedef gboolean (*GMarshalFunc_BOOLEAN__STRING_BOXED) (gpointer     data1,
-                                                          gpointer     arg_1,
-                                                          gpointer     arg_2,
-                                                          gpointer     data2);
-  register GMarshalFunc_BOOLEAN__STRING_BOXED callback;
+  typedef void (*GMarshalFunc_VOID__STRING_BOXED) (gpointer     data1,
+                                                   gpointer     arg_1,
+                                                   gpointer     arg_2,
+                                                   gpointer     data2);
+  register GMarshalFunc_VOID__STRING_BOXED callback;
   register GCClosure *cc = (GCClosure*) closure;
   register gpointer data1, data2;
-  gboolean v_return;
 
-  g_return_if_fail (return_value != NULL);
   g_return_if_fail (n_param_values == 3);
 
   if (G_CCLOSURE_SWAP_DATA (closure))
@@ -124,14 +118,12 @@ _gio_marshal_BOOLEAN__STRING_BOXED (GClosure     *closure,
       data1 = g_value_peek_pointer (param_values + 0);
       data2 = closure->data;
     }
-  callback = (GMarshalFunc_BOOLEAN__STRING_BOXED) (marshal_data ? marshal_data : cc->callback);
+  callback = (GMarshalFunc_VOID__STRING_BOXED) (marshal_data ? marshal_data : cc->callback);
 
-  v_return = callback (data1,
-                       g_marshal_value_peek_string (param_values + 1),
-                       g_marshal_value_peek_boxed (param_values + 2),
-                       data2);
-
-  g_value_set_boolean (return_value, v_return);
+  callback (data1,
+            g_marshal_value_peek_string (param_values + 1),
+            g_marshal_value_peek_boxed (param_values + 2),
+            data2);
 }
 
 /* VOID:BOOLEAN,POINTER (./gio-marshal.list:3) */
