@@ -176,7 +176,7 @@ g_date_update_julian (const GDate *const_d)
 {
   GDate *d = (GDate *) const_d;
   GDateYear year;
-  gint index;
+  gint idx;
   
   g_return_if_fail (d != NULL);
   g_return_if_fail (d->dmy);
@@ -184,10 +184,10 @@ g_date_update_julian (const GDate *const_d)
   g_return_if_fail (g_date_valid_dmy (d->day, d->month, d->year));
   
   /* What we actually do is: multiply years * 365 days in the year,
-   *  add the number of years divided by 4, subtract the number of
-   *  years divided by 100 and add the number of years divided by 400,
-   *  which accounts for leap year stuff. Code from Steffen Beyer's
-   *  DateCalc. 
+   * add the number of years divided by 4, subtract the number of
+   * years divided by 100 and add the number of years divided by 400,
+   * which accounts for leap year stuff. Code from Steffen Beyer's
+   * DateCalc. 
    */
   
   year = d->year - 1; /* we know d->year > 0 since it's valid */
@@ -197,9 +197,9 @@ g_date_update_julian (const GDate *const_d)
   d->julian_days -= (year /= 25); /* divides original # years by 100 */
   d->julian_days += year >> 2;    /* divides by 4, which divides original by 400 */
   
-  index = g_date_is_leap_year (d->year) ? 1 : 0;
+  idx = g_date_is_leap_year (d->year) ? 1 : 0;
   
-  d->julian_days += days_in_year[index][d->month] + d->day;
+  d->julian_days += days_in_year[idx][d->month] + d->day;
   
   g_return_if_fail (g_date_valid_julian (d->julian_days));
   
@@ -321,7 +321,7 @@ g_date_get_julian (const GDate *d)
 guint        
 g_date_get_day_of_year (const GDate *d)
 {
-  gint index;
+  gint idx;
   
   g_return_val_if_fail (g_date_valid (d), 0);
   
@@ -330,9 +330,9 @@ g_date_get_day_of_year (const GDate *d)
 
   g_return_val_if_fail (d->dmy, 0);  
   
-  index = g_date_is_leap_year (d->year) ? 1 : 0;
+  idx = g_date_is_leap_year (d->year) ? 1 : 0;
   
-  return (days_in_year[index][d->month] + d->day);
+  return (days_in_year[idx][d->month] + d->day);
 }
 
 guint        
@@ -672,7 +672,9 @@ g_date_prepare_to_parse (const gchar      *str,
           ++i;
         }
       if (using_twodigit_years)
-	DEBUG_MSG (("**Using twodigit years with cutoff year: %u", twodigit_start_year));
+        {
+	  DEBUG_MSG (("**Using twodigit years with cutoff year: %u", twodigit_start_year));
+        }
       { 
         gchar *strings[3];
         i = 0;
@@ -851,7 +853,9 @@ g_date_set_parse (GDate       *d,
     }
 #ifdef G_ENABLE_DEBUG
   else 
-    DEBUG_MSG (("Rejected DMY %u %u %u", day, m, y));
+    {
+      DEBUG_MSG (("Rejected DMY %u %u %u", day, m, y));
+    }
 #endif
   G_UNLOCK (g_date_global);
 }
@@ -1053,7 +1057,7 @@ g_date_is_first_of_month (const GDate *d)
 gboolean     
 g_date_is_last_of_month (const GDate *d)
 {
-  gint index;
+  gint idx;
   
   g_return_val_if_fail (g_date_valid (d), FALSE);
   
@@ -1062,9 +1066,9 @@ g_date_is_last_of_month (const GDate *d)
 
   g_return_val_if_fail (d->dmy, FALSE);  
   
-  index = g_date_is_leap_year (d->year) ? 1 : 0;
+  idx = g_date_is_leap_year (d->year) ? 1 : 0;
   
-  if (d->day == days_in_months[index][d->month]) return TRUE;
+  if (d->day == days_in_months[idx][d->month]) return TRUE;
   else return FALSE;
 }
 
@@ -1104,7 +1108,7 @@ g_date_add_months (GDate *d,
                    guint  nmonths)
 {
   guint years, months;
-  gint index;
+  gint idx;
   
   g_return_if_fail (g_date_valid (d));
   
@@ -1121,10 +1125,10 @@ g_date_add_months (GDate *d,
   d->month = months + 1;
   d->year  += years;
   
-  index = g_date_is_leap_year (d->year) ? 1 : 0;
+  idx = g_date_is_leap_year (d->year) ? 1 : 0;
   
-  if (d->day > days_in_months[index][d->month])
-    d->day = days_in_months[index][d->month];
+  if (d->day > days_in_months[idx][d->month])
+    d->day = days_in_months[idx][d->month];
   
   d->julian = FALSE;
   
@@ -1136,7 +1140,7 @@ g_date_subtract_months (GDate *d,
                         guint  nmonths)
 {
   guint years, months;
-  gint index;
+  gint idx;
   
   g_return_if_fail (g_date_valid (d));
   
@@ -1160,10 +1164,10 @@ g_date_subtract_months (GDate *d,
       d->year -= 1;
     }
   
-  index = g_date_is_leap_year (d->year) ? 1 : 0;
+  idx = g_date_is_leap_year (d->year) ? 1 : 0;
   
-  if (d->day > days_in_months[index][d->month])
-    d->day = days_in_months[index][d->month];
+  if (d->day > days_in_months[idx][d->month])
+    d->day = days_in_months[idx][d->month];
   
   d->julian = FALSE;
   
@@ -1228,14 +1232,14 @@ guint8
 g_date_get_days_in_month (GDateMonth month, 
                           GDateYear  year)
 {
-  gint index;
+  gint idx;
   
   g_return_val_if_fail (g_date_valid_year (year), 0);
   g_return_val_if_fail (g_date_valid_month (month), 0);
   
-  index = g_date_is_leap_year (year) ? 1 : 0;
+  idx = g_date_is_leap_year (year) ? 1 : 0;
   
-  return days_in_months[index][month];
+  return days_in_months[idx][month];
 }
 
 guint8       
